# -*- coding: utf-8 -*-
# @Author: Gx
# @Date:   2019-04-17 15:27:11
# @Last Modified by:   Administrator
# @Last Modified time: 2019-04-18 08:35:20
import tensorflow as tf
def add_layer(input, in_size, out_size, name="default",activation_func= None, Batch_Normalizaiton= False):
	'添加一层全连接层，输入维度，输出维度，name， 可选 激活函数和批标准化(BN)'
	Weights = tf.Variable(tf.random_normal([in_size,out_size]),dtype=tf.float32)
	Biases = tf.Variable(tf.random_normal([1, out_size]), dtype=tf.float32)
	result = tf.matmul(input, Weights) + Biases
	if Batch_Normalizaiton:
		result = BN(result, out_size)


	if activation_func is None:
		return result
	else:
		return eval(activation_func)(result)
def add_conv(input, kernel, strides= [1,1,1,1], padding= "SAME"):
	'''
		输入数据[batch, height, width, channels], 
		kernel[kheight,kwidth, input_channel, out_channel],
		strides步长 这里我们只用了中间的两个值 [1, stride, stride, 1]
		padding string类型，值为“SAME” 和 “VALID”，表示的是卷积的形式，是否考虑边界。
							   "SAME"是考虑边界，不足的时候用0去填充周围，"VALID"则不考虑
	'''
	return tf.nn.conv2d(input, kernel, strides, padding)
def pooling(input, ksize=[1,2,2,1] , strides=[1,2,2,1] , padding="SAME" , poolop= "tf.nn.max_pool"):
	'''
		第一个参数value：需要做池化的输入图像，输入feaure map，因为池化在卷积后边。shape为[batch, in_height, in_width, in_channels]：
		batch：训练时一个batch的图片数量
		in_height：输入图像的高度
		in_width：输入图像的宽度
		in_channels：输入feature map的数量
		第二个参数ksize：类似于卷积的过滤器，池化窗口的大小，是一个长度为4的一维数组，但是这个数组的第一个和最后一数必须为1，即[1, height, width, 1]。这意味着池化层的过滤器是不可以在batch和channels上做池化。实际应用中，使用最多的过滤器尺寸为[1, 2, 2, 1]或者[1, 3, 3, 1]。

		height:过滤器的高度
		width：过滤器的宽度
		第三个参数strides：不同维度上的步长，是一个长度为4的一维向量，[ 1, strides, strides, 1]，第一维和最后一维的数字要求必须是1。因为卷积层的步长只对矩阵的长和宽有效。

		第四个参数padding：string类型，是否考虑边界，值为“SAME”和“VALID”，"SAME"是考虑边界，不足的时候用填充周围，"VALID"则不考虑边界。。
	'''
	# return poolop(input,)
	return eval(poolop)(input, ksize, strides, padding)
def BN(Wx_plus_b,output_size):
	'添加 Batch_Normalizaiton(批标准化)， 校正数据'
	fc_mean, fc_var = tf.nn.moments(Wx_plus_b, axes=[0])
	scale = tf.Variable(tf.ones([output_size]))
	shift = tf.Variable(tf.zeros([output_size]))
	epsilon = 0.001
	Wx_plus_b = tf.nn.batch_normalization(Wx_plus_b, fc_mean, fc_var, shift, scale, epsilon)
	return Wx_plus_b



def _t():
	print("this t ")
def _main():
	_t()

	pass
if __name__ == '__main__':
	_main()


import os
import cv2

def debug(func):
	def work(*args, **kwargs):
		try:
			print("_debug")
			func(*args, **kwargs)
		except:
			print("except exit")
	return work
@debug
def video_display(path):
	'single video display: 播放当前path的video'
	video_capture = cv2.VideoCapture(path)
	fps = video_capture.get(cv2.CAP_PROP_FPS)
	flag, frame = video_capture.read()
	winname = ""
	try:
		if len(path.split("/")) == 1:
			winname= path.split(".")[0]
		else:
			winname= path.split("/")[-1].split(".")[0]
	except:
		print("some wrong may result, program exit with 0")
	while flag:
		cv2.imshow(winname, frame)
		flag, frame = video_capture.read()

		KeyBoardListenser = cv2.waitKey(10)
		if KeyBoardListenser == 27: #esc 
			break		
	cv2.destroyAllWindows()
	print("finished")		


import tkinter as tk
from tkinter import filedialog
import os
import sys
def get_One_File(filetypes = [("text file", "*.txt"),("image file", ("*.jpg","*.png","*.svg")),("all","*.*")]):
	'基于tkinter 获取文件， 默认为*.txt,或*.*'
	# 获取一个文件
	root = tk.Tk()
	root.withdraw()
	file_path = filedialog.askopenfilename(filetypes=filetypes, initialdir = os.getcwd())
	if file_path=="":
		return False, ""
	else:
		return True, file_path

def _get_Multi_file():
	'同时获取多个文件，功能待完善'
	root = tk.Tk()
	root.withdraw() 
	file_path = filedialog.askopenfilenames()
	for f in file_path:
		fo = f.split('.')[0]+'.csv'
		with open(fo,'w') as foo:
			with open(f,'r') as fn:
				fn.readline()
				for line in fn.readlines():
					li = line.strip().split()
					foo.write('%f,%f\n'%(float(li[1]),float(li[0])))
					print(li)
def get_Folder():
	'获取一个文件夹路径，第一个返回值是flag 表示是否获取正确 的路径,第二个返回值是path'
	root = tk.Tk()
	root.withdraw()
	path_="myname"
	path_ = filedialog.askdirectory(initialdir = os.getcwd())
	if path_=="":
		return False, ""
	else:
		return True, path_

if __name__ == '__main__':
	# main()
	flag , path_= get_One_File()
	if flag:
		print(path_)
	else:
		print("path wrong")
	flag , path_= get_Folder()
	if flag:
		print(path_)
	else:
		print("path wrong")


'Gx 包下的图片处理'

def read_img(filename):
	import cv2
	import np as np
	global cv2
	global np
	'使用 imdecode方法能够访问到包含中文字符的图片'
	try:
		arr = cv2.imdecode(np.fromfile(filename, dtype= np.uint8), -1)
	except:
		print("error with filename")
	return np.array(arr)
	pass
def write_img(dir, frame):
	import cv2
	import np as np
	global cv2
	global np
	'使用 cv2 imencode 方法写入图片，防止出现中文字符的问题'
	try:
		suffix = "."+dir.strip().split(".")[-1]
		cv2.imencode(suffix, frame)[1].tofile(dir)
		return True
	except:
		print("errors result")
		return  False
	pass

def _main():
	arr = read_img("./image.jpg")
	print(arr)
	write_img("./my.seg",arr)
	print(arr.shape)
	pass
if __name__ == '__main__':
	_main()




'''
    file package to deal with the file problems
    currently , it contain one py :
    get_filename.py, it obtain get_One_File (choose to obtain file path)、get_Folder(choose to obtain folder path) functions
    ...to be updated
'''


# -*- coding: utf-8 -*-
# @Author: Gx
# @Date:   2019-04-15 15:19:08
# @Last Modified by:   Administrator
# @Last Modified time: 2019-04-18 08:39:10
'''
ultilize the tensorflow library to deal with the problem in the question
contains:
	1. ty.py, which contain the main func, like BN、fully-Connected、CNN etc... to be updateds
	2. ...to be updated
'''



'''
    cv package for deal with the computer vision
    current the package obtain :
        1. CreateVideo.py contain video_display function, input a path create a video display
        2. Image.py contain read_img, write_img functions currently.
        ... to be updated
'''


# -*- coding: utf-8 -*-
# @Author: Gx
# @Date:   2019-04-15 15:19:08
# @Last Modified by:   Administrator
# @Last Modified time: 2019-04-16 08:56:51
'''
Gx is a scavenger s` life code. can be summarize as these:

1. cv package , which are used to deal with computer vision
2. file package , which are used to deal with file、folder and others operating system
3. np package , which are used to deal with array in numpy
4. time package , which are used to deal with the time
'''



import sys

from PyQt5.QtCore import QSize, Qt
from PyQt5.QtGui import QIcon
from PyQt5.QtWidgets import QApplication, QWidget, QPushButton, QHBoxLayout, QVBoxLayout, QLabel
from qtpy import QtWidgets


def create_win(title="window", size=(1920,1080),move = (0,0)):
    '''
    create a window
    :param title: 窗口的标题名字
    :param size:  一个元组 用于定于windows的大小,
    :param move:  move元组相比于原来windows的位置
    :return: 
    '''
    app = QApplication(sys.argv)
    w = QWidget()
    w.resize(size[0], size[1])
    w.move(move[0],move[1])

    w.setWindowTitle(title)
    w.show()
    sys.exit(app.exec_())

def create_win2(title="window", size=(1920,1080),move = (0,0)):
    '''
    create a window
    :param title: 窗口的标题名字
    :param size:  一个元组 用于定于windows的大小,
    :param move:  move元组相比于原来windows的位置
    :return:
    '''
    app = QApplication(sys.argv)
    w = QWidget()
    w.resize(size[0], size[1])
    w.move(move[0],move[1])
    w.setGeometry(300,300,300,200)
    btn = QPushButton('Buttion')

    w.setWindowTitle(title)
    w.setWindowIcon(QIcon('image.jpg'))
    w.show()
    sys.exit(app.exec_())

def t3():
    w = QWidget()
    w.setMinimumSize(QSize(1200, 600))
    layout = QHBoxLayout()
    layout2 = QHBoxLayout()

    layout_s = QVBoxLayout()
    btnW = QtWidgets.QWidget()

    ImageWidget = QtWidgets.QWidget()

    btn = QPushButton()
    # btn.clicked.connect()
    btn.setText("load_image")
    layout.addWidget(btn, alignment=Qt.AlignTop)

    btn_2 = QPushButton()
    # btn_2.clicked.connect(self.load_text)
    btn_2.setText("beauty")
    layout.addWidget(btn_2, alignment=Qt.AlignTop)
    btnW.setLayout(layout)

    label = QLabel()
    layout2.addWidget(label, alignment=Qt.AlignVCenter)

    label2 = QLabel()
    layout2.addWidget(label2, alignment=Qt.AlignTop)
    ImageWidget.setLayout(layout2)
    layout_s.addWidget(btnW)
    layout_s.addWidget(ImageWidget, alignment=Qt.AlignTop)

    w.setWindowTitle("beauty")

    w.setLayout(layout_s)
if __name__ == '__main__':
    t3()


'用于获取当前时间'
import time
def _getms():
	return str(int((time.time()%1) *1000))
def get_time(param):
	'''以时间戳的形式返回, param控制返回格式
		1 返回时间戳
		2 返回时间时间元组
		3 以字符串的形式返回YYYY-MM-DD-HH-MM-SS 格式
		4 在3的基础上输出毫秒信息
		5 待添加
	'''
	if param == 1 :
		return time.time()
	elif param == 2:
		return time.localtime()
	elif param == 3:
		return time.strftime('%Y_%m_%d_%Hh_%Mm_%Ss', time.localtime(time.time()))
	# import time
	elif param == 4:
		return time.strftime('%Y_%m_%d_%Hh_%Mm_%Ss', time.localtime(time.time()))+"_"+_getms()+"ms"
	else:
		print("param mistakes , please recheck it !")
		return ""

if __name__ == '__main__':
	print(get_time(4))


# -*- coding: utf-8 -*-
# @Author: Gx
# @Date:   2019-04-15 15:10:25
# @Last Modified by:   Administrator
# @Last Modified time: 2019-04-18 08:51:19
#!/usr/bin/env python
# coding=utf-8

from setuptools import setup, find_packages
'Mylife code'
setup(
    name='Gx',
    version='1.0.3',
    description=(
        'A Scavenger `s code in his whole life'
    ),
    long_description=('A Scavenger in his hometown\n 大风起兮云飞扬\n威加海内兮归故乡\n安得猛士兮守四方 '),
    author='WRQ',
    author_email='wrq2149678246@qq.com',
    maintainer='wrq,',
    maintainer_email='wrq2149678246@qq.com',
    license='BSD License',
    packages=find_packages(),
    platforms=["all"],
    url='',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Operating System :: OS Independent',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Programming Language :: Python',
        'Programming Language :: Python :: Implementation',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Topic :: Software Development :: Libraries'
    ],
)